## Nexosis API Client Library

[![Build Status](https://travis-ci.org/Nexosis/nexosisclient-py.svg?branch=master)](https://travis-ci.org/Nexosis/nexosisclient-py)

This software is provided as a way to include Nexosis API functionality in your own Python software.

You can read about the Nexosis API at [https://developers.nexosis.com](https://developers.nexosis.com/docs/services/98847a3fbbe64f73aa959d3cededb3af)

Install with pip:

```bash
pip install nexosisclient
```

*Pull requests are welcome*